<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>CCanvas</name>
    <message>
        <location filename="../canvas/CCanvas.cpp" line="89"/>
        <source>No map view available.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CCommandProcessor</name>
    <message>
        <location filename="../setup/CCommandProcessor.cpp" line="31"/>
        <source>Print debug output to console.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../setup/CCommandProcessor.cpp" line="34"/>
        <source>Print debug output to logfile (temp. path).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../setup/CCommandProcessor.cpp" line="37"/>
        <source>Do not show splash screen.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../setup/CCommandProcessor.cpp" line="40"/>
        <source>File with QMapTool configuration.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../setup/CCommandProcessor.cpp" line="40"/>
        <source>file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CDialogRefPoint</name>
    <message>
        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="39"/>
        <source>bad coordinate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="58"/>
        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="64"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="58"/>
        <source>Bad value for X pixel.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="64"/>
        <source>Bad value for Y pixel.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CDrawContextPixel</name>
    <message>
        <location filename="../canvas/CDrawContextPixel.cpp" line="74"/>
        <source>Failed to load</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CDrawContextProj</name>
    <message>
        <location filename="../canvas/CDrawContextProj.cpp" line="72"/>
        <source>Failed to load</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CGdalFile</name>
    <message>
        <location filename="../helpers/CGdalFile.cpp" line="53"/>
        <location filename="../helpers/CGdalFile.cpp" line="81"/>
        <location filename="../helpers/CGdalFile.cpp" line="111"/>
        <source>Error...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../helpers/CGdalFile.cpp" line="53"/>
        <location filename="../helpers/CGdalFile.cpp" line="81"/>
        <source>Failed to load file: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../helpers/CGdalFile.cpp" line="111"/>
        <source>File must be 8 bit palette or gray indexed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../helpers/CGdalFile.cpp" line="196"/>
        <source>(color table)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../helpers/CGdalFile.cpp" line="200"/>
        <source>(RGB)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../helpers/CGdalFile.cpp" line="204"/>
        <source>(RGBA)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../helpers/CGdalFile.cpp" line="208"/>
        <source>(unknown)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CGridPlacer</name>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="34"/>
        <source>Select one of the corners and place the marker at the corresponding grid crossing on the map. All 4 corners have to be placed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="160"/>
        <source>Point 1 - not set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="164"/>
        <source>Point 1 - ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="169"/>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="174"/>
        <source>Point 1 - bad</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="185"/>
        <source>Point 2 - ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="190"/>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="195"/>
        <source>Point 2 - bad</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="207"/>
        <source>Point 3 - ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="212"/>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="217"/>
        <source>Point 3 - bad</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="229"/>
        <source>Point 4 - ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="234"/>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="239"/>
        <source>Point 4 - bad</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="181"/>
        <source>Point 2 - not set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="203"/>
        <source>Point 3 - not set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="225"/>
        <source>Point 4 - not set</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CGridSelArea</name>
    <message>
        <location filename="../overlay/gridtool/CGridSelArea.cpp" line="30"/>
        <source>Select the area to be covered by the calculated reference points. Simply grab the corners of the selection rectangle with a left click and place them where you want with a second click.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CGridSetRef</name>
    <message>
        <location filename="../overlay/gridtool/CGridSetRef.cpp" line="37"/>
        <source>Valid coordinate formats: If the projection is lat/lon all values have to be in degree, e.g. &quot;48.2&quot; or &quot;12.4&quot;. For all other projections values are either in multiple of meter or feet. If you are doing it wrong the entry field will turn red.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CHelp</name>
    <message>
        <location filename="../../common/help/CHelp.cpp" line="31"/>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../common/help/CHelp.cpp" line="46"/>
        <source>Content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../common/help/CHelp.cpp" line="47"/>
        <source>Index</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../common/help/CHelp.cpp" line="48"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CHelpIndex</name>
    <message>
        <location filename="../../common/help/CHelpIndex.cpp" line="29"/>
        <source>Search:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CHelpSearch</name>
    <message>
        <location filename="../../common/help/CHelpSearch.cpp" line="31"/>
        <source>Search:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CItemListWidget</name>
    <message>
        <location filename="../items/CItemListWidget.cpp" line="103"/>
        <source>Select files...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CItemMapLayer</name>
    <message>
        <location filename="../items/CItemMapLayer.cpp" line="34"/>
        <source>Layer</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CItemTreeWidget</name>
    <message>
        <location filename="../items/CItemTreeWidget.cpp" line="159"/>
        <source>&lt;p&gt;The current map &lt;i&gt;&apos;%1&apos;&lt;/i&gt; does not match the projection of previous loaded maps. All map files need to have the same projection.&lt;/p&gt;&lt;p&gt;&lt;b&gt;This file&lt;/b&gt;: %2&lt;/p&gt;&lt;p&gt;&lt;b&gt;Expected&lt;/b&gt;: %3&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/CItemTreeWidget.cpp" line="164"/>
        <source>Error...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/CItemTreeWidget.cpp" line="235"/>
        <source>Select files...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>COverlayCutMap</name>
    <message>
        <location filename="../overlay/COverlayCutMap.cpp" line="222"/>
        <source>Delete mask...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/COverlayCutMap.cpp" line="222"/>
        <source>Are you sure to delete complete mask?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/COverlayCutMap.cpp" line="239"/>
        <source>Save mask...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/COverlayCutMap.cpp" line="287"/>
        <source>Load mask...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/COverlayCutMap.cpp" line="301"/>
        <source>Failed...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/COverlayCutMap.cpp" line="301"/>
        <source>Not a shape file.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>COverlayGridTool</name>
    <message>
        <location filename="../overlay/COverlayGridTool.cpp" line="34"/>
        <source>Before you proceed with &apos;ok&apos;:
Please cross check all data once again. A bad reference coordinate will ruin all the work. Also cross check if the selected area contains as many reference points as possible at the border. You can easily delete points outside the map in the Reference Tool. But it&apos;s much more effort to set additional points in case you miss some.  When you are done press &apos;ok&apos; to transfer the derived reference points to the Reference Tool.

The next step will be to use the Reference Tool to adjust the position of all reference points to the real grid position on the map.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>COverlayRefMap</name>
    <message>
        <location filename="../overlay/COverlayRefMap.cpp" line="42"/>
        <source>If you used the Grid Tool you have to fine tune the reference points by placing them as much as possible on the grid crossing. Be aware that if you over scale you get jumping points by rounding effects. Be precise but do not make religion out of the task.
If your mouse focus is on the map you can use the N and B keys to jump forward an backward in the reference point list. 
The is also the option to fine tune the reference points in auto-mode. In this mode the next reference point is selected automatically right after you placed the current one. This is very convenient for a large number of reference points.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/COverlayRefMap.cpp" line="614"/>
        <source>Save reference points...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/COverlayRefMap.cpp" line="653"/>
        <source>Load reference points...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/COverlayRefMap.cpp" line="694"/>
        <source>Delete all reference points...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/COverlayRefMap.cpp" line="694"/>
        <source>Are you sure to delete all reference points in the list?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/COverlayRefMap.cpp" line="729"/>
        <source>Delete...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/COverlayRefMap.cpp" line="729"/>
        <source>Delete all selected reference points?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>COverlayRefMapPoint</name>
    <message>
        <location filename="../overlay/refmap/COverlayRefMapPoint.cpp" line="43"/>
        <source>bad coordinate</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CProjWizard</name>
    <message>
        <location filename="../overlay/refmap/CProjWizard.cpp" line="62"/>
        <source>north</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/CProjWizard.cpp" line="63"/>
        <source>south</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/CProjWizard.cpp" line="227"/>
        <source>Error...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/CProjWizard.cpp" line="227"/>
        <source>The value
&apos;%1&apos;
is not a valid coordinate system definition:
%2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CSetupExtTools</name>
    <message>
        <location filename="../setup/CSetupExtTools.cpp" line="63"/>
        <location filename="../setup/CSetupExtTools.cpp" line="64"/>
        <location filename="../setup/CSetupExtTools.cpp" line="65"/>
        <location filename="../setup/CSetupExtTools.cpp" line="66"/>
        <location filename="../setup/CSetupExtTools.cpp" line="67"/>
        <location filename="../setup/CSetupExtTools.cpp" line="68"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;not found&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../setup/CSetupExtTools.cpp" line="80"/>
        <source>Select %1 binary...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CShell</name>
    <message>
        <location filename="../shell/CShell.cpp" line="41"/>
        <source>Execution of external program `%1` failed: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shell/CShell.cpp" line="45"/>
        <source>Process cannot be started.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shell/CShell.cpp" line="46"/>
        <source>Make sure the required packages are installed, `%1` exists and is executable.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shell/CShell.cpp" line="50"/>
        <source>External process crashed.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shell/CShell.cpp" line="54"/>
        <source>An unknown error occurred.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shell/CShell.cpp" line="146"/>
        <source>!!! failed !!!
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shell/CShell.cpp" line="161"/>
        <source>
Canceled by user&apos;s request.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shell/CShell.cpp" line="191"/>
        <source>!!! done !!!
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CToolAddOverview</name>
    <message>
        <location filename="../tool/CToolAddOverview.cpp" line="30"/>
        <source>Add Overviews</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/CToolAddOverview.cpp" line="32"/>
        <source>Raster map files consume quite some memory if a larger area is displayed. Pre-calculated overview levels help to speed up loading and displaying the map. These overviews can be stored within the map file as well as an external file. GDAL can remove internally stored overviews, however it will not free the used space in the file. Therefore it&apos;s size will remain large. If you do not like that use the external option.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CToolCutMap</name>
    <message>
        <location filename="../tool/CToolCutMap.cpp" line="30"/>
        <source>Cut Map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/CToolCutMap.cpp" line="32"/>
        <source>Paper maps usually have a border you don&apos;t want to have. To combine maps seamlessly you have to cut that border, replacing it by transparent pixel. This tool allows you to define a cut line and it will add an alpha channel for transparency to your map.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CToolExport</name>
    <message>
        <location filename="../tool/CToolExport.cpp" line="30"/>
        <source>Export Maps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/CToolExport.cpp" line="33"/>
        <source>To use the maps on your device you have to export them to the proprietary format supported by the device. Depending on the device this can vary from a single layer map to a map stack with maps of different scale.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/CToolExport.cpp" line="41"/>
        <source>Note: This tool will use all files in the list as a input. This will only work if all files have the same projection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/CToolExport.cpp" line="114"/>
        <source>Select filename...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CToolGrid</name>
    <message>
        <location filename="../tool/CToolGrid.cpp" line="37"/>
        <source>By placing 4 reference points at the corners of a grid square and referencing them by their top left corner, the width and height, all the other grid points can be estimated.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CToolPalettize</name>
    <message>
        <location filename="../tool/CToolPalettize.cpp" line="30"/>
        <source>Add Color Palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/CToolPalettize.cpp" line="34"/>
        <source>Usually you use RGBA color while referencing a map because the large color space allows you to scale and rotate the map without any loss of quality. But it results into rather large files. The file size can be optimized by using a color palette instead of the RGBA color space. The impact on quality is low as long as you do not want to scale or rotate the map. If you want to combine files with a color palette all files need to have the same palette.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/CToolPalettize.cpp" line="46"/>
        <source>Note: This tool will use all files in the list as a combined input to derive an optimal palette. This will only work if all files have the same projection and scale.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/CToolPalettize.cpp" line="109"/>
        <source>Select filename...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CToolRefMap</name>
    <message>
        <location filename="../tool/CToolRefMap.cpp" line="34"/>
        <source>Reference Map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/CToolRefMap.cpp" line="36"/>
        <source>A scan of a paper map can be converted to a referenced raster map if you place at least three reference points on the map. The more points the better the result. If your map has a grid you can place points on that grid with the grid tool.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IAbout</name>
    <message>
        <location filename="../IAbout.ui" line="14"/>
        <source>About...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../IAbout.ui" line="26"/>
        <source>&lt;b&gt;QMapTool&lt;/b&gt;, Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../IAbout.ui" line="39"/>
        <location filename="../IAbout.ui" line="77"/>
        <location filename="../IAbout.ui" line="91"/>
        <location filename="../IAbout.ui" line="105"/>
        <source>TextLabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../IAbout.ui" line="70"/>
        <source>Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../IAbout.ui" line="84"/>
        <source>GDAL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../IAbout.ui" line="98"/>
        <source>Proj4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../IAbout.ui" line="121"/>
        <source>This software is licensed under GPL3 or any later version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../IAbout.ui" line="128"/>
        <source>© 2017 Oliver Eichler (oliver.eichler@gmx.de)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ICoordFormatSetup</name>
    <message>
        <location filename="../units/ICoordFormatSetup.ui" line="14"/>
        <source>Coordinate Format...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../units/ICoordFormatSetup.ui" line="24"/>
        <source>N48° 53&apos; 39.6&quot; E13° 31&apos; 6.78&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../units/ICoordFormatSetup.ui" line="31"/>
        <source>N48.8943° E013.51855°</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../units/ICoordFormatSetup.ui" line="38"/>
        <source>N48° 53.660 E013° 31.113</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../units/ICoordFormatSetup.ui" line="53"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; For some GUI elements changing the units will not take effect until you restart QMapTool.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IDialogRefPoint</name>
    <message>
        <location filename="../overlay/refmap/IDialogRefPoint.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IDialogRefPoint.ui" line="25"/>
        <source>Coord. Map File [pixel]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IDialogRefPoint.ui" line="32"/>
        <source>x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IDialogRefPoint.ui" line="42"/>
        <source>y</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IDialogRefPoint.ui" line="49"/>
        <source>Coord. lat/lon WGS84 [°]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IDialogRefPoint.ui" line="59"/>
        <source>Bad position format. Must be: 
&quot;[N|S] ddd mm.sss [W|E] ddd mm.sss&quot;
or
&quot;[N|S] ddd.ddd [W|E] ddd.ddd&quot;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IGridPlacer</name>
    <message>
        <location filename="../overlay/gridtool/IGridPlacer.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridPlacer.ui" line="150"/>
        <source>Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridPlacer.ui" line="224"/>
        <source>Set Area</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IGridSelArea</name>
    <message>
        <location filename="../overlay/gridtool/IGridSelArea.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridSelArea.ui" line="35"/>
        <source>TextLabel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IGridSetRef</name>
    <message>
        <location filename="../overlay/gridtool/IGridSetRef.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridSetRef.ui" line="35"/>
        <source>Grid Projection:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridSetRef.ui" line="47"/>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridSetRef.ui" line="60"/>
        <source>TextLabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridSetRef.ui" line="72"/>
        <source>Easting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridSetRef.ui" line="82"/>
        <source>Horiz. Spacing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridSetRef.ui" line="92"/>
        <source>Northing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridSetRef.ui" line="102"/>
        <source>Vert. Spacing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IItemListWidget</name>
    <message>
        <location filename="../items/IItemListWidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/IItemListWidget.ui" line="40"/>
        <source>Add map files to list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/IItemListWidget.ui" line="43"/>
        <location filename="../items/IItemListWidget.ui" line="60"/>
        <location filename="../items/IItemListWidget.ui" line="77"/>
        <location filename="../items/IItemListWidget.ui" line="94"/>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/IItemListWidget.ui" line="57"/>
        <source>Remove selected file from the list.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/IItemListWidget.ui" line="74"/>
        <source>Clear complete list of map files.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/IItemListWidget.ui" line="91"/>
        <source>Reload the currently selected map.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IItemTreeWidget</name>
    <message>
        <location filename="../items/IItemTreeWidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/IItemTreeWidget.ui" line="40"/>
        <source>Add map files to list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/IItemTreeWidget.ui" line="43"/>
        <location filename="../items/IItemTreeWidget.ui" line="60"/>
        <location filename="../items/IItemTreeWidget.ui" line="77"/>
        <location filename="../items/IItemTreeWidget.ui" line="94"/>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/IItemTreeWidget.ui" line="57"/>
        <source>Remove selected file from the list.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/IItemTreeWidget.ui" line="74"/>
        <source>Clear complete list of map files.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/IItemTreeWidget.ui" line="91"/>
        <source>Reload the currently selected map.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IMainWindow</name>
    <message>
        <location filename="../IMainWindow.ui" line="14"/>
        <source>MainWindow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="32"/>
        <source>Setup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="41"/>
        <source>View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="47"/>
        <source>Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="52"/>
        <source>?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="68"/>
        <source>Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="101"/>
        <source>Shell</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="120"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="129"/>
        <source>Ext. Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="132"/>
        <source>Setup paths to external tools, like gdalwarp etc.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="144"/>
        <location filename="../IMainWindow.ui" line="147"/>
        <source>Flip Mouse Wheel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="156"/>
        <location filename="../IMainWindow.ui" line="159"/>
        <source>Setup Units</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="168"/>
        <source>Setup Coord. Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="171"/>
        <source>Change the format coordinates are displayed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="182"/>
        <source>Show Tool Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="191"/>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="194"/>
        <source>F1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IOverlayCutMap</name>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="35"/>
        <source>Just move the map and zoom.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="58"/>
        <source>Add point to mask.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="61"/>
        <location filename="../overlay/IOverlayCutMap.ui" line="84"/>
        <location filename="../overlay/IOverlayCutMap.ui" line="107"/>
        <location filename="../overlay/IOverlayCutMap.ui" line="137"/>
        <location filename="../overlay/IOverlayCutMap.ui" line="158"/>
        <location filename="../overlay/IOverlayCutMap.ui" line="175"/>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="81"/>
        <source>Move point of mask.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="104"/>
        <source>Remove point from mask.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="134"/>
        <source>Remove complete cut mask.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="155"/>
        <source>Load cut mask from shape file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="172"/>
        <source>Save cut mask to shape file.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IOverlayGridTool</name>
    <message>
        <location filename="../overlay/IOverlayGridTool.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayGridTool.ui" line="145"/>
        <source>do not translate</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IOverlayRefMap</name>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="40"/>
        <source>Just move the map and zoom.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="63"/>
        <source>Add reference point.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="66"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="89"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="112"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="135"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="165"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="179"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="200"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="217"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="244"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="326"/>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="86"/>
        <source>Move reference point.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="109"/>
        <source>Remove single reference point.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="132"/>
        <source>Move reference points with auto mode. This will pickup the next point after you moved a reference point.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="162"/>
        <source>Remove all reference points.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="176"/>
        <source>Switch to the Grid Tool.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="197"/>
        <source>Load reference points from GCP file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="214"/>
        <source>Save reference points into GCP file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="241"/>
        <source>Sort list of reference points.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="281"/>
        <source>(x, y)[pixel]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="286"/>
        <source>(lat, lon)[°]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="294"/>
        <source>TextLabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="304"/>
        <source>Final Map Projection:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="316"/>
        <source>Enter a valid projection string. Valid strings are &quot;+proj...&quot; or &quot;+init=epsg:...&quot;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="323"/>
        <source>Start projection wizard.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="343"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IProjWizard</name>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="14"/>
        <source>Proj4 Wizard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="29"/>
        <source>Mercator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="38"/>
        <source>UTM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="45"/>
        <source>zone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="82"/>
        <source>user defined</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="94"/>
        <source>Datum</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="104"/>
        <source>World Mercator (OSM)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="124"/>
        <source>Result:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="138"/>
        <source>UPS North (North Pole)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="145"/>
        <source>UPS South (South Pole)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="152"/>
        <source>Projection</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ISetupExtTools</name>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="14"/>
        <source>Setup Ext. Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="22"/>
        <location filename="../setup/ISetupExtTools.ui" line="64"/>
        <location filename="../setup/ISetupExtTools.ui" line="99"/>
        <location filename="../setup/ISetupExtTools.ui" line="173"/>
        <location filename="../setup/ISetupExtTools.ui" line="194"/>
        <location filename="../setup/ISetupExtTools.ui" line="257"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;not found&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="32"/>
        <location filename="../setup/ISetupExtTools.ui" line="53"/>
        <location filename="../setup/ISetupExtTools.ui" line="74"/>
        <location filename="../setup/ISetupExtTools.ui" line="88"/>
        <location filename="../setup/ISetupExtTools.ui" line="135"/>
        <location filename="../setup/ISetupExtTools.ui" line="149"/>
        <location filename="../setup/ISetupExtTools.ui" line="183"/>
        <location filename="../setup/ISetupExtTools.ui" line="211"/>
        <location filename="../setup/ISetupExtTools.ui" line="225"/>
        <location filename="../setup/ISetupExtTools.ui" line="239"/>
        <location filename="../setup/ISetupExtTools.ui" line="264"/>
        <location filename="../setup/ISetupExtTools.ui" line="275"/>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="112"/>
        <source>gdal_translate:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="43"/>
        <source>gdalbuildvrt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="166"/>
        <source>gdaladdo:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="125"/>
        <source>gdalwarp:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="29"/>
        <location filename="../setup/ISetupExtTools.ui" line="132"/>
        <location filename="../setup/ISetupExtTools.ui" line="180"/>
        <location filename="../setup/ISetupExtTools.ui" line="208"/>
        <location filename="../setup/ISetupExtTools.ui" line="222"/>
        <source>Setup user defined path.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="201"/>
        <source>qmt_rgb2pct</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="50"/>
        <location filename="../setup/ISetupExtTools.ui" line="71"/>
        <location filename="../setup/ISetupExtTools.ui" line="85"/>
        <location filename="../setup/ISetupExtTools.ui" line="146"/>
        <location filename="../setup/ISetupExtTools.ui" line="236"/>
        <source>Reset user defined path setup.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="250"/>
        <source>qmt_map2jnx</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="288"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; Usually QMapTool should detect all external tools by itself. If it does not, it&apos;s a bad setup and you should fix the PATH variable of your system. You can setup the paths manually, too, if you know what you are doing. But please keep in mind that GDAL needs a proper environment setup to function properly. If it&apos;s not setup properly you might get results but these can be off grid.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ITimeZoneSetup</name>
    <message>
        <location filename="../units/ITimeZoneSetup.ui" line="14"/>
        <source>Setup Time Zone ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../units/ITimeZoneSetup.ui" line="22"/>
        <source>UTC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../units/ITimeZoneSetup.ui" line="32"/>
        <source>Local</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../units/ITimeZoneSetup.ui" line="42"/>
        <source>Automatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../units/ITimeZoneSetup.ui" line="75"/>
        <source>Print date/time in </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../units/ITimeZoneSetup.ui" line="82"/>
        <source>long format, or</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../units/ITimeZoneSetup.ui" line="92"/>
        <source>short format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IToolAddOverview</name>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="59"/>
        <source>do not translate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="119"/>
        <source>:2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="126"/>
        <source>:4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="133"/>
        <source>:8</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="140"/>
        <source>:16</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="147"/>
        <source>:32</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="154"/>
        <source>:64</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="164"/>
        <source>Remove all overview levels from map file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="167"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="174"/>
        <source>Do not copy the overviews into the file itself. Add them as external file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="177"/>
        <source>Overview as external file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="207"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="221"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="232"/>
        <source>For all files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="257"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;gdaladdo&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IToolCutMap</name>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="59"/>
        <source>do not translate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="114"/>
        <source>Output filename suffix</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="133"/>
        <source>_cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="148"/>
        <source>Create overviews for result.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="176"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="190"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="201"/>
        <source>For all files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="226"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;gdalwarp&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="236"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;gdaladdo&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IToolExport</name>
    <message>
        <location filename="../tool/IToolExport.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="59"/>
        <location filename="../tool/IToolExport.ui" line="72"/>
        <source>do not translate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="83"/>
        <source>Garmin BirdsEye (*.jnx)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="88"/>
        <source>TwoNav Raster (*.rmap)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="101"/>
        <source>not implemented yet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="112"/>
        <source>Target File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="130"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="144"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="173"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;qmt_map2jnx&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="184"/>
        <source>Target Filename</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IToolExportJnx</name>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="35"/>
        <location filename="../tool/export/IToolExportJnx.ui" line="81"/>
        <source>BirdsEye</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="50"/>
        <source>Product ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="57"/>
        <source>Copyright notice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="64"/>
        <location filename="../tool/export/IToolExportJnx.ui" line="95"/>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="71"/>
        <source>Product name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="88"/>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="105"/>
        <source>JPEG</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="133"/>
        <source>Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="140"/>
        <source>Chroma subsampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="148"/>
        <source>411</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="153"/>
        <source>422</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="158"/>
        <source>444</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="169"/>
        <source>Device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="184"/>
        <source>Z-Order</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IToolGrid</name>
    <message>
        <location filename="../tool/IToolGrid.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolGrid.ui" line="56"/>
        <source>Grid Tool</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolGrid.ui" line="65"/>
        <source>do not translate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolGrid.ui" line="99"/>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolGrid.ui" line="110"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolGrid.ui" line="134"/>
        <source>Reset</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IToolOverviewGroupBox</name>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="14"/>
        <source>GroupBox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="71"/>
        <source>:2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="78"/>
        <source>:4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="85"/>
        <source>:8</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="92"/>
        <source>:16</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="99"/>
        <source>:32</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="106"/>
        <source>:64</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="119"/>
        <source>Do not copy the overviews into the file itself. Add them as external file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="122"/>
        <source>Overview as external file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IToolPalettize</name>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="65"/>
        <location filename="../tool/IToolPalettize.ui" line="78"/>
        <source>do not translate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="96"/>
        <source>Single files, filename suffix</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="109"/>
        <source>_8bit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="123"/>
        <source>Combined file, filename:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="135"/>
        <source>Embed result into *.vrt file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="142"/>
        <source>Create overviews for result.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="170"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="184"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="213"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;gdaladdo&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="223"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;gdal_translate&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="233"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;qmt_rgb2pct&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="247"/>
        <source>Select filename</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IToolRefMap</name>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="59"/>
        <source>do not translate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="113"/>
        <source>Output filename suffix</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="132"/>
        <source>_ref</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="144"/>
        <source>Embed result into *.vrt file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="151"/>
        <source>Create overviews for result.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="179"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="193"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="204"/>
        <source>For all files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="229"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;gdalwarp&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="239"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;gdal_translate&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="249"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;gdaladdo&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IUnit</name>
    <message>
        <location filename="../units/IUnit.cpp" line="740"/>
        <location filename="../units/IUnit.cpp" line="746"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../units/IUnit.cpp" line="740"/>
        <source>Bad position format. Must be: &quot;[N|S] ddd mm.sss [W|E] ddd mm.sss&quot; or &quot;[N|S] ddd.ddd [W|E] ddd.ddd&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../units/IUnit.cpp" line="746"/>
        <source>Position values out of bounds. </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IUnitsSetup</name>
    <message>
        <location filename="../units/IUnitsSetup.ui" line="14"/>
        <source>Setup units...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../units/IUnitsSetup.ui" line="24"/>
        <source>Nautical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../units/IUnitsSetup.ui" line="31"/>
        <source>Imperial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../units/IUnitsSetup.ui" line="38"/>
        <source>Metric</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../units/IUnitsSetup.ui" line="53"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; For some GUI elements changing the units will not take effect until you restart QMapTool.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
